@@ -65,7 +65,7 @@ ServerConfigModule::ServerConfigModule(QWidget* parent, const QVariantList& args
 
     setupUi(this);
 
-    QPixmap pixmap = KIcon("baloo").pixmap(IconSize(KIconLoader::Desktop));
+    const QPixmap pixmap = KIcon(QLatin1String("baloo")).pixmap(IconSize(KIconLoader::Desktop));
     m_pixmapLabel->setPixmap(pixmap);
 
     connect(m_folderSelectionWidget, SIGNAL(changed()),
@@ -85,7 +85,7 @@ ServerConfigModule::~ServerConfigModule()
 void ServerConfigModule::load()
 {
     // File indexer settings
-    KConfig config("baloofilerc");
+    KConfig config(QLatin1String("baloofilerc"));
     KConfigGroup group = config.group("General");
 
     KConfigGroup basicSettings = config.group("Basic Settings");
@@ -107,7 +107,7 @@ void ServerConfigModule::save()
     QStringList excludeFolders = m_folderSelectionWidget->excludeFolders();
 
     // Change the settings
-    KConfig config("baloofilerc");
+    KConfig config(QLatin1String("baloofilerc"));
     KConfigGroup basicSettings = config.group("Basic Settings");
 
     bool mountPointsEx = m_folderSelectionWidget->allMountPointsExcluded();
@@ -156,7 +156,7 @@ void ServerConfigModule::defaults()
 
 void ServerConfigModule::folderSelectionChanged()
 {
-    bool disabled = m_folderSelectionWidget->allMountPointsExcluded();
+    const bool disabled = m_folderSelectionWidget->allMountPointsExcluded();
     m_enableCheckbox->setChecked(!disabled);
 }
 
